---
feature_story: FS_80_45_89_81
feature_title: integrated functions
feature_status: TODO
---

Meta functions are those built-in ones which are not domain-specific.

List:
*   `func_id_unplugged`: func which is not plugged anywhere.
*   `func_id_intercept_invocation`: [FS_88_66_66_73][FS_88_66_66_73]
*   `list_envelope`: TODO: func with cardinality hooks on client side: found 0, found 1, found N.
*   `get_envelope`: TODO: FS_74_69_61_79: should work as (A) query single envelope (with zero error code), otherwise (B) see `list_envelope` (with non-zero error code).
*   `set_envelope`: TODO: FS_74_69_61_79: should work as (A) del prev queried envelope, (B) add next provided envelope body.
*   `dump_config`: TODO: dump server or client config view.
*   `echo_args`: [FS_43_50_57_71][FS_43_50_57_71]
*   `func_id_query_enum_items`: [FS_02_25_41_81][FS_02_25_41_81]: enumerate available arg options
*   `propose_values`: TODO: same function which list values by Tab-completion (if we want func for Alt+Shift+Q action, we want func for Tab action).
*   `error_message`: TODO: util func with optional exit_code and error_message (logic is already provided by ErrorDelegator, but not accessible as func).


FS_88_66_66_73: FS_88_66_66_73.func_id_intercept_invocation.md
FS_43_50_57_71: FS_43_50_57_71.func_id_echo_args.md
FS_71_87_33_52: FS_71_87_33_52.func_id_help_hint.md
FS_02_25_41_81: FS_02_25_41_81.func_id_query_enum_items.md
